/****************************************************************************************** 
 *	Chili DirectX Framework Version 12.04.24											  *	
 *	Game.cpp																			  *
 *	Copyright 2012 PlanetChili.net														  *
 *																						  *
 *	This file is part of The Chili DirectX Framework.									  *
 *																						  *
 *	The Chili DirectX Framework is free software: you can redistribute it and/or modify	  *
 *	it under the terms of the GNU General Public License as published by				  *
 *	the Free Software Foundation, either version 3 of the License, or					  *
 *	(at your option) any later version.													  *
 *																						  *
 *	The Chili DirectX Framework is distributed in the hope that it will be useful,		  *
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of						  *
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the						  *
 *	GNU General Public License for more details.										  *
 *																						  *
 *	You should have received a copy of the GNU General Public License					  *
 *	along with The Chili DirectX Framework.  If not, see <http://www.gnu.org/licenses/>.  *
 ******************************************************************************************/
#include "Game.h"
#include <stdlib.h>
#include <time.h>
#include <math.h>

Game::Game( HWND hWnd,const KeyboardServer& kServer,const MouseServer& mServer )
:	gfx( hWnd ),
	audio( hWnd ),
	kbd( kServer ),
	mouse( mServer ),
	cameraX(0),
	cameraY(0),
	boxX(0),
	boxY(550),
	boxWidth(SCREENWIDTH - 1),
	boxHeight(SCREENHEIGHT - 1),
	nPlatforms(NBOXES),
	cx(WORLDWIDTH - 200 ),
	cy(400 ),
	rad(1),
	playerX(90),
	playerY(435),
	jumpHeight(350),
	playerHP(105),
	
	drawLaser(true),
	PlayerOnGround(true),
	//PlayerOnPlatform(false),
	canJump(true),
	PlayerFacingRight(true),
	isPlayerDead(false),
	
	keyPressedLastFrame(false)
{
	CanPlayerShootR = true;
	for(int index = 0; index < 5; index++)
	{
		ParticleX[index] = cx;
		ParticleY[index] = cy;
		side[index] = 0;
		enemyDead[index] = false;
	}
	isLitUp[0] = true;
	isLitUp[1] = true;
	isLitUp[2] = false;
	isLitUp[3] = true;
	enemyCoord();
	
}
//test
void Game::Go()
{
	gfx.BeginFrame();
	ComposeFrame();
	gfx.EndFrame();
	if(isPlayerDead == false)
	{
		UpdateCamera();
		UpdatePlayer();
		UpdateEnemy();
		UpdateBullet();
		theJump();
	}
	
}
void Game::level1()
{
	if(isPlayerDead == false)
	{
		Part1();
	}
	
}
void Game::Part1()
{
	boxCoord(); //coords. for level platforms and level death hole
	
	drawBackground(cameraX,cameraY); //draw background on bottom layer so the player is clearly visible
	DrawTeleporter();

	int xx = WORLDWIDTH - 80;
	int yy = 62;
	
	gfx.DrawDoorClipped(xx - cameraX,yy - cameraY);//draw exit door
	for(int index = 0; index < nPlatforms; index++)
	{
		int psx = platformX[index] - cameraX; //level platforms
		int wsx = platformWidth[index] - cameraX;
		
		int hsx = holeX - cameraX; //level death hole
		int hwsx = holeWidth - cameraX;
	
		if( psx < 0 || psx + 24 > SCREENWIDTH - 1 || wsx < 0 || wsx > SCREENWIDTH - 1 ) //check if level platforms are off screen
		{
			gfx.DrawBoxClipped(psx,platformY[index],wsx,platformHeight[index],0,128,0); // partially on-screen so draw clipped
		}
	
		else
		{
			gfx.DrawBoxUnclipped(psx,platformY[index], wsx, platformHeight[index],0,128,0); //on-screen so draw unclipped
		}
		
		if( hsx < 0 || hsx + 24 > SCREENWIDTH - 1 || hwsx < 0 || hwsx > SCREENWIDTH - 1 )//check if level death hole is of screen
		{
			gfx.DrawBoxClipped(hsx,holeY,hwsx,holeHeight,0,0,0); // partially on-screen so draw clipped
		}
	
		else
		{
			gfx.DrawBoxUnclipped(hsx,holeY,hwsx,holeHeight,0,0,0); //on-screen so draw unclipped
		}
	}
	for(int index = 0; index < 4; index++)
	{
		gfx.DrawMiniGame(LightX[index] - cameraX,LightY[index] - cameraY,buttonX[index] - cameraX, buttonY[index] - cameraY, buttonWidth[index] - cameraX, buttonHeight[index] - cameraY);
		if(isLitUp[index] == true)
		{
			gfx.DrawDisc(LightX[index] - cameraX, LightY[index] - cameraY,15,255,255,0);
		}
	}
	if(isLitUp[0] == true && isLitUp[1] == true && isLitUp[2] == true && isLitUp[3] == true)
	{
		drawLaser = false;
	}
	
	int lx = cx - 150 - cameraX;
	if(drawLaser == true)
	{
		gfx.DrawLineClipped(lx,190,lx,550,255,0,0);
	}
	if(!keyPressedLastFrame) //for the mini game
	{
		if(mouse.GetMouseX() > buttonX[0] - cameraX && mouse.GetMouseX() < buttonWidth[0] - cameraX && mouse.GetMouseY() > buttonY[0] && mouse.GetMouseY() < buttonHeight[0] && mouse.LeftIsPressed() )
		{
			keyPressedLastFrame = true;
		
			if(isLitUp[0] == true)
			{
				isLitUp[0] = false;
			}
			else if(isLitUp[0] == false)
			{
				isLitUp[0] = true;
			}
			if(isLitUp[1] == true)
			{
				isLitUp[1] = false;
			}
			else if(isLitUp[1] == false)
			{
				isLitUp[1] = true;
			}
		}
		else if(mouse.GetMouseX() > buttonX[1] - cameraX && mouse.GetMouseX() < buttonWidth[1] - cameraX && mouse.GetMouseY() > buttonY[1] && mouse.GetMouseY() < buttonHeight[1] && mouse.LeftIsPressed() )
		{
			keyPressedLastFrame = true;
		
			if(isLitUp[1] == true)
			{
				isLitUp[1] = false;
			}
			else if(isLitUp[1] == false)
			{
				isLitUp[1] = true;
			}
			if(isLitUp[2] == true)
			{
				isLitUp[2] = false;
			}
			else if(isLitUp[2] == false)
			{
				isLitUp[2] = true;
			}
		}
		else if(mouse.GetMouseX() > buttonX[2] - cameraX && mouse.GetMouseX() < buttonWidth[2] - cameraX && mouse.GetMouseY() > buttonY[2] && mouse.GetMouseY() < buttonHeight[2] && mouse.LeftIsPressed() )
		{
			keyPressedLastFrame = true;
			if(isLitUp[3] == true)
			{
				isLitUp[3] = false;
			}
			else if(isLitUp[3] == false)
			{
				isLitUp[3] = true;
			}
			if(isLitUp[2] == true)
			{
				isLitUp[2] = false;
			}
			else if(isLitUp[2] == false)
			{
				isLitUp[2] = true;
			}
		}
		else if(mouse.GetMouseX() > buttonX[3] - cameraX && mouse.GetMouseX() < buttonWidth[3] - cameraX && mouse.GetMouseY() > buttonY[3] && mouse.GetMouseY() < buttonHeight[3] && mouse.LeftIsPressed() )
		{
			keyPressedLastFrame = true;
			if(isLitUp[3] == true)
			{
				isLitUp[3] = false;
			}
			else if(isLitUp[3] == false)
			{
				isLitUp[3] = true;
			}
			if(isLitUp[0] == true)
			{
				isLitUp[0] = false;
			}
			else if(isLitUp[0] == false)
			{
				isLitUp[0] = true;
			}
			if(isLitUp[2] == true)
			{
				isLitUp[2] = false;
			}
			else if(isLitUp[2] == false)
			{
				isLitUp[2] = true;
			}
		}
	}
	else if(!(mouse.LeftIsPressed()))
	{
		keyPressedLastFrame = false;
	}
	
	//if the mini game isnt beat draw the laser door PART 1, go to PART 1
	if(drawLaser == true)
	{
		if(playerX + 85 - cameraX >= cx - 150 - cameraX)
		{
			playerX = cx - 235;
		}
	}
	//if player moves into teleporter, go to PART 1
	if(playerX - cameraX > cx - 30 - cameraX && playerX - cameraX < cx + 30 - cameraX && playerY > cy - 30 && playerY < cy + 30 )
	{
		playerX = 1970;
		playerY = 76;
	}

	if(side[0] == 0)	// enemy movements, on set path, go to PART 1
	{
		if(enemyX[0]<= 425)
		{
			enemyX[0]-=1;
			enemyHP[0]-=1;
			if(enemyX[0]==20)
			{
				side[0] = 1;
			}
		}
	}
	if(side[0] == 1)
	{
		if(enemyX[0] >= 20)
		{
			enemyX[0]+=1;
			enemyHP[0]+=1;
			if(enemyX[0] == 425)
			{
				side[0] = 0;
			}
		}
	}
	
	if(side[1] == 0)
	{
		if(enemyX[1]<= 385)
		{
			enemyX[1]-=1;
			enemyHP[1]-=1;
			if(enemyX[1]==315)
			{
				side[1] = 1;
			}
		}
	}
	if(side[1] == 1)
	{
		if(enemyX[1] >= 315)
		{
			enemyX[1]+=1;
			enemyHP[1]+=1;
			if(enemyX[1] == 385)
			{
				side[1] = 0;
			}
		}
	}
	
	if(side[2] == 0)
	{
		if(enemyX[2]>= 1240)
		{
			enemyX[2]+=1;
			enemyHP[2]+=1;
			if(enemyX[2]==2100)
			{
				side[2] = 1;
			}
		}
	}
	if(side[2] == 1)
	{
		if(enemyX[2] <= 2100)
		{
			enemyX[2]-=1;
			enemyHP[2]-=1;
			if(enemyX[2] == 1240)
			{
				side[2] = 0;
			}
		}
	}

	if(side[3] == 0)
	{
		if(enemyX[3]<= 2550)
		{
			enemyX[3]-=1;
			enemyHP[3]-=1;
			if(enemyX[3]==2385)
			{
				side[3] = 1;
			}
		}
	}
	if(side[3] == 1)
	{
		if(enemyX[3] >= 2385)
		{
			enemyX[3]+=1;
			enemyHP[3]+=1;
			if(enemyX[3] == 2550)
			{
				side[3] = 0;
			}
		}
	}

	if(side[4] == 0)
	{
		if(enemyX[4]<= 2555)
		{
			enemyX[4]-=1;
			enemyHP[4]-=1;
			if(enemyX[4]==2385)
			{
				side[4] = 1;
			}
		}
	}
	if(side[4] == 1)
	{
		if(enemyX[4] >= 2385)
		{
			enemyX[4]+=1;
			enemyHP[4]+=1;
			if(enemyX[4] == 2550)
			{
				side[4] = 0;
			}
		}
	}
}
void Game::boxCoord()
{
	
	holeX = 450;
	holeY = 550;
	holeWidth = 970;
	holeHeight = 599;

	platformX[0] = 300;
	platformX[1] = 525;
	platformX[2] = 800;
	platformX[3] = 1020;
	platformX[4] = 1070;
	platformX[5] = 1570 ;
	platformX[6] = 1270;
	platformX[7] = 1970;
	platformX[8] = 2120;
	platformX[9] = 2270;
	platformX[10] =2370 ;

	platformWidth[0] = 400;
	platformWidth[1] = 625;
	platformWidth[2] = 850; 
	platformWidth[3] = 1220;
	platformWidth[4] = 1170;
	platformWidth[5] = 1770;
	platformWidth[6] = 1370;
	platformWidth[7] = WORLDWIDTH - 1;
	platformWidth[8] = 2270;
	platformWidth[9] = 2370;
	platformWidth[10] = 2570;

	platformY[0] = 410;
	platformY[1] = 275; 
	platformY[2] = 425; 
	platformY[3] = 290; 
	platformY[4] = 161;
	platformY[5] = 161; 
	platformY[6] = 340;
	platformY[7] = 161;
	platformY[8] = 500;
	platformY[9] = 375; 
	platformY[10] = 300; 
	//
	platformHeight[0] = 435;
	platformHeight[1] = 300; 
	platformHeight[2] = 450; 
	platformHeight[3] = 550; 
	platformHeight[4] = 190; 
	platformHeight[5] = 190; 
	platformHeight[6] = 379; 
	platformHeight[7] = 190;
	platformHeight[8] = 550;
	platformHeight[9] = 550;
	platformHeight[10] = 550; 

	LightX[0] = WORLDWIDTH - 650;
	LightX[1] = WORLDWIDTH - 600;
	LightX[2] = WORLDWIDTH - 550;
	LightX[3] = WORLDWIDTH - 500;

	LightY[0] = 300;
	LightY[1] = 300;
	LightY[2] = 300;
	LightY[3] = 300;

	buttonX[0] = LightX[0] - 5;
	buttonX[1] = LightX[1] - 5;
	buttonX[2] = LightX[2] - 5;
	buttonX[3] = LightX[3] - 5;

	buttonY[0] = 350;
	buttonY[1] = 350;
	buttonY[2] = 350;
	buttonY[3] = 350;

	buttonWidth[0] = LightX[0] + 5;
	buttonWidth[1] = LightX[1] + 5;;
	buttonWidth[2] = LightX[2] + 5;;
	buttonWidth[3] = LightX[3] + 5;;

	buttonHeight[0] = 380;
	buttonHeight[1] = 380;
	buttonHeight[2] = 380;
	buttonHeight[3] = 380;

}
void Game::enemyCoord()
{
	enemyX[0] = 425;
	enemyX[1] = 385;
	enemyX[2] = 1240;
	enemyX[3] = 2515;
	enemyX[4] = 2550;

	enemyY[0] = 485;
	enemyY[1] = 345;
	enemyY[2] = 485;
	enemyY[3] = 235;
	enemyY[4] = 235;

	enemyHP[0] = enemyX[0] + 15;
	enemyHP[1] = enemyX[1] + 15;
	enemyHP[2] = enemyX[2] + 15;
	enemyHP[3] = enemyX[3] + 15;
	enemyHP[4] = enemyX[4] + 15;
}
void Game::drawBackground(int cameraX, int cameraY)
{
	// horizontal lines (rows)
	// we calculate the offset of the first row from the top of the
	// screen using cameraY % GRIDRESOLUTION, and then we just keep drawing rows every
	// GRIDRESOLUTION pixels until we reach the bottom of the screen
	for( int y = GRIDRESOLUTION - cameraY % GRIDRESOLUTION; y < SCREENHEIGHT; y += GRIDRESOLUTION )
	{
		gfx.DrawLine( 0,y,SCREENWIDTH-1,y,0,0,0 );
	}

	// vertical lines (columns)
	for( int x = GRIDRESOLUTION - cameraX % GRIDRESOLUTION; x < SCREENWIDTH; x += GRIDRESOLUTION )
	{
		gfx.DrawLine( x,0,x,SCREENHEIGHT-1,0,0,0 );
	}

	// world borders
	if( cameraY == 0 )
	{
		gfx.DrawLine( 0,0,SCREENWIDTH-1,0,255,0,0 );
	}
	if( cameraX == 0 )
	{
		gfx.DrawLine( 0,0,0,SCREENHEIGHT-1,255,0,0 );
	}
	if( cameraY == WORLDHEIGHT - SCREENHEIGHT )
	{
		gfx.DrawLine( 0,SCREENHEIGHT-1,SCREENWIDTH-1,SCREENHEIGHT-1,255,0,0 );
	}
	if( cameraX == WORLDWIDTH - SCREENWIDTH )
	{
		gfx.DrawLine( SCREENWIDTH-1,0,SCREENWIDTH-1,SCREENHEIGHT-1,255,0,0 );
	}
	gfx.DrawBoxClipped(boxX,boxY,boxWidth,boxHeight - cameraY,0,128,0);
	gfx.DrawSpike(1,1,128,128,128);
}
void Game::UpdateCamera()
{
	
	// convert face world coordinates to screen coordinates
	int facesx = playerX - cameraX;
	int facesy = playerY - cameraY;

	// scroll camera if face is out of tracking rectangle
	if( facesx < CTRKOFFHOR )
	{
		cameraX = playerX - CTRKOFFHOR;
	}
	if( facesx + 24 > SCREENWIDTH - CTRKOFFHOR )
	{
		cameraX = playerX + 24 + CTRKOFFHOR - SCREENWIDTH;
	}
	if( facesy < CTRKOFFVERT )
	{
		cameraY = playerY - CTRKOFFVERT;
	}
	if( facesy + 24 > SCREENHEIGHT - CTRKOFFVERT )
	{
		cameraY = playerY + 24 + CTRKOFFVERT - SCREENHEIGHT;
	}

	// clamp camera so that the screen does not exceed
	// the edge of the world
	if( cameraX < 0 )
	{
		cameraX = 0;
	}
	else if( cameraX + SCREENWIDTH > WORLDWIDTH )
	{
		cameraX = WORLDWIDTH - SCREENWIDTH;
	}
	if( cameraY < 0 )
	{
		cameraY = 0;
	}
	else if( cameraY + SCREENHEIGHT > WORLDHEIGHT )
	{
		cameraY = WORLDHEIGHT - SCREENHEIGHT;
	}
}
void Game::UpdatePlayer()
{
	int speed = 5;
	gfx.DrawBoxClipped(5,50,playerHP,60,255,0,0);
	if(isPlayerDead == false)
	{
		if(!keyPressedLastFrame && canJump == true)
		{
			if(kbd.UpIsPressed() )
			{
				keyPressedLastFrame = true;	//player jumps
				PlayerOnGround = false;
			}
		}
	
		else if(!(kbd.UpIsPressed() || mouse.LeftIsPressed()))
		{
			keyPressedLastFrame = false;
		}	
	
		if(kbd.DownIsPressed()) // move player down
		{
			playerY++;
		}
	
		if( kbd.LeftIsPressed() ) //move player left
		{
			playerX = playerX - speed;  
		}
	
		if( kbd.RightIsPressed() ) //move player right
		{
			playerX = playerX + speed;	
		}

		if( playerX - 85 < 0 ) //clamp player to left side
		{
			playerX = 85;
		}

		if( playerX + 90 > WORLDWIDTH ) //clamp player to right side
		{
			playerX = WORLDWIDTH - 90;
		}
	
		if( playerY < 15 ) //clamp player to top 
		{
			playerY = 15;
		}

		if( playerY + 20 > WORLDHEIGHT )// clamp player to bottom
		{
			playerY = WORLDHEIGHT - 20;
		}
	
		//if player is able to shoot and bullet hasnt reach max distance, draw the bullet
		if(CanPlayerShootR == false && bulletXR < (playerX + 150) - cameraX)
		{
			gfx.DrawBullet(bulletXR,playerY - cameraY);	
		}
		//check to see if player is on level platform
		for(int index = 0; index < nPlatforms; index++)
		{
			if( playerY + 56 > platformY[index] && playerX - cameraX > platformX[index] - cameraX && playerX - cameraX < platformWidth[index] - cameraX)
			{
				PlayerOnPlatform = true;
			}
			else
			{
				PlayerOnPlatform = false;
			}
		}
		for(int index = 0; index < nPlatforms; index++) //check to see if player is colliding with level blocks NEEDS TO GO TO UPDATE PLAYER
		{
			if(playerX - cameraX > platformX[index] - cameraX 
				&& playerX - cameraX < platformWidth[index] - cameraX  //this if statment checks for player under-side collision
				&& playerY - 10 > platformY[index]
				&& playerY - 10 < platformHeight[index] )
			{
				playerY = platformHeight[index] + 10;
			}
	
			if(playerX + 10 - cameraX > platformX[index] - cameraX 
				&& playerX - cameraX < platformWidth[index] - cameraX  //this if statment checks for player left-side collision 
				&& playerY - 10 > platformY[index] - 65 
				&& playerY - 10 < platformHeight[index])
			{
				playerX = platformX[index] - 10;
			}

			if(playerX + 10 - cameraX > platformX[index] - cameraX
				&& playerX  - cameraX < platformWidth[index] - cameraX //this if statement checks for player top-side collision
				&& playerY + 58 > platformY[index]
				&& playerY < platformHeight[index])
			{
				playerY = platformY[index] - 58;
				jumpHeight = platformY[index] - 200;
				PlayerOnPlatform = true;
			}

			if(playerX - cameraX > platformX[index] - cameraX
				&& playerX - 10 - cameraX < platformWidth[index] - cameraX //this if statment checks for player right-side collision
				&& playerY - 10 > platformY[index] - 65
				&& playerY - 10 < platformHeight[index])
			{
				playerX = platformWidth[index] + 10;
			}

	
		}
	
		//floor collision NEEDS TO GO TO UPDATE PLAYER

		if(playerY + 56 > boxY && playerX - cameraX < holeX - cameraX || playerY + 56 > boxY && playerX - cameraX > holeWidth - cameraX)
		{
			playerY = boxY - 56;
			jumpHeight = 350;
			canJump = true;
		}
	
		else if(PlayerOnPlatform == true)
		{
			canJump = true;
		}
	
		else
		{
			canJump = false;
		}

	}
	
	

	//need code for side of hole collision. When touched, player jumps to top of floor
}
void Game::UpdateEnemy()
{
	for(int index = 0; index < 5; index++)
	{
		//enemyHP[index] = enemyX[index] + 15;
		int ex = enemyX[index] - cameraX;
		//if bullet hits enemy bring down enemys health by 15
		if(bulletXR + 85 > ex - 5 && bulletXR + 85 < ex + 5 && playerY - cameraY > enemyY[index] && playerY - cameraY < enemyY[index] + 65 && CanPlayerShootR == false)
		{
			enemyHP[index]-=15;
			CanPlayerShootR = true;
		}
		//if enemy hits player, player loses 25 hp and the enemy dies
		if(bulletXR  > ex - 5 && bulletXR  < ex + 5 && playerY - cameraY > enemyY[index] - 64 && playerY - cameraY < enemyY[index] + 65 )
		{
			if(enemyDead[index] == false && CanPlayerShootR == true)
			{
				playerHP = playerHP - 25;
			}
			enemyDead[index] = true;
		}
		//if all enemy health runs out the enemy dies
		if(enemyHP[index] <= enemyX[index] - 15)
		{
			enemyDead[index] = true;
		}
		if(isPlayerDead == false)
		{
			//if the enemy is still alive, draw the enemy
			if(enemyDead[index] == false)
			{
				//int ex = enemyX[index] - cameraX;
				int ey = enemyY[index] - cameraY;
				gfx.DrawEnemy(enemyX[index] - cameraX,enemyY[index] - cameraY);
				gfx.DrawBoxClipped(ex - 15, ey - 10, enemyHP[index] - cameraX, ey - 5,255,255,0);
			}
		}
		
	}
	
}
void Game::UpdateBullet()
{	
	 if(kbd.SpaceIsPressed()) //set spacebar to shoot
		{
			CanPlayerShootR = false;
		}
		
		if(CanPlayerShootR == true) //if the spacebar has not been pressed, bullet-x coords are set
		{
			bulletXR  = playerX  - cameraX;
		}
		
		if(CanPlayerShootR == false && bulletXR < (playerX + 199) - cameraX) //if bullet has been fired and
		{																	 //if bullet is less than 199 pixels away from player(max shoot distance)
			bulletXR = bulletXR + 8;										 //increase the bullet's x postion by 8 pixels a frame
		}
		
		if(bulletXR > (playerX + 199) - cameraX) //if the bullet has reached max shoot distance, stop drawing, and give user to shoot again
		{
			CanPlayerShootR = true;
		}
	}
void Game::DrawTeleporter()
{
	for(int index = 0; index < 5; index++)
	{
		gfx.DrawParticleClipped(ParticleX[index] - cameraX, ParticleY[index] - cameraY,255,255,255);
	}
	gfx.DrawDisc(cx - cameraX,cy - cameraY,30,0,0,255);
	if(rad < 30)
	{
		gfx.DrawDisc(cx - cameraX,cy - cameraY,rad,255,255,255);
		rad++;
	}
	if(rad == 30)
	{
		rad = 0;
	}
	if(rad > 15)
	{
		gfx.DrawDisc(cx - cameraX,cy - cameraY,rad - 10,0,0,255);
	}
	if(ParticleX[0] < cx + 100)
	{
		ParticleX[0]+=8;
		ParticleY[0]-=8;
		if(ParticleX[0] > cx + 100)
		{
			ParticleX[0] = cx;
			ParticleY[0] = cy;
		}
	}
	if(ParticleX[1] > cx - 100 )
	{
		ParticleX[1]-=8;
		ParticleY[1]-=8;
		if(ParticleX[1] < cx - 100)
		{
			ParticleX[1] = cx;
			ParticleY[1] = cy;
		}
	}
	if(ParticleX[2] > cx - 100)
	{
		ParticleX[2]-=8;
		ParticleY[2]+=8;
		if(ParticleX[2] < cx - 100)
		{
			ParticleX[2] = cx;
			ParticleY[2] = cy;
		}
	}
	if(ParticleX[3] < cx + 100)
	{
		ParticleX[3]+=8;
		ParticleY[3]+=8;
		if(ParticleX[3] > cx + 100)
		{
			ParticleX[3] = cx;
			ParticleY[3] = cy;
		}
	}
}
void Game::theJump()
{
	if(PlayerOnGround == false)
			{
				//canJump = false;
				jump = 4;
				playerY-=jump; 
				if(jump > -4)
				{
					jump -=0.1f;
				}
				for(int index = 0;index < nPlatforms;index++)
				{
					if(playerY - 10 <= platformHeight[index] && playerX > platformX[index] && playerX < platformWidth[index] && playerY > platformY[index]|| playerY < 15)
					{
						PlayerTouchingBottom = true;
					}
				}
				if(playerY - cameraY < jumpHeight || PlayerTouchingBottom == true)
				{
					PlayerOnGround = true;
					PlayerTouchingBottom = false;
				}
				
			}
		if(PlayerOnGround == true)
		{
			playerY +=3 - cameraY;
		}
		
		
}
void Game::ComposeFrame()
{
	level1();
	if(isPlayerDead == false)
	{
		gfx.DrawPlayer(playerX - cameraX  ,playerY - cameraY);
	}
	
	int xx = WORLDWIDTH - 80;
	int yy = 62;
	if(playerHP <= 0)
	{
		isPlayerDead = true;
	}
	
	
	
	else if(playerX + 20 - cameraX > xx - cameraX && playerY - cameraY > yy - cameraY && playerY - cameraY < yy + 100 - cameraY)
	{
		isPlayerDead = true;
	}
	else if(playerY - cameraY < 20)
	{
		isPlayerDead = true;
	}
	else if(playerX > holeX - cameraX && playerX < holeWidth - cameraX && playerY + 56 > holeY)
	{
		isPlayerDead = true;
	}
	if(isPlayerDead == true)
	{
		gfx.DrawGameOver(400,300);
	}
}


