/****************************************************************************************** 
 *	Chili DirectX Framework Version 12.04.24											  *	
 *	Game.h																				  *
 *	Copyright 2012 PlanetChili.net														  *
 *																						  *
 *	This file is part of The Chili DirectX Framework.									  *
 *																						  *
 *	The Chili DirectX Framework is free software: you can redistribute it and/or modify	  *
 *	it under the terms of the GNU General Public License as published by				  *
 *	the Free Software Foundation, either version 3 of the License, or					  *
 *	(at your option) any later version.													  *
 *																						  *
 *	The Chili DirectX Framework is distributed in the hope that it will be useful,		  *
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of						  *
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the						  *
 *	GNU General Public License for more details.										  *
 *																						  *
 *	You should have received a copy of the GNU General Public License					  *
 *	along with The Chili DirectX Framework.  If not, see <http://www.gnu.org/licenses/>.  *
 ******************************************************************************************/
#pragma once

#include "D3DGraphics.h"
#include "Keyboard.h"
#include "Mouse.h"
#include "Sound.h"
#define WORLDWIDTH 4000
#define WORLDHEIGHT 1199
// resolution of background grid
#define GRIDRESOLUTION 50
// camera tracking offset vertical/horizontal
// is the offset from the edge off the screen 
// to the camera tracking rectangle
#define CTRKOFFVERT 50
#define CTRKOFFHOR 240
#define NBOXES 11

class Game
{
	public:
	Game( HWND hWnd,const KeyboardServer& kServer,const MouseServer& mServer );
	void Go();
private:
	void ComposeFrame();
	/********************************/
	/*  User Functions              */
		void UpdatePlayer();
		void UpdateEnemy();
		void UpdateBullet();
		void UpdateCamera();
		

		void drawBackground(int cameraX, int cameraY);
		void DrawTeleporter();
		void DrawPlayer(int x, int y);
		
		void boxCoord();
		void enemyCoord();
		void theJump();
		
		void level1();
		void Part1();
	/********************************/
private:
	D3DGraphics gfx;
	KeyboardClient kbd;
	MouseClient mouse;
	DSound audio;
	/********************************/
	/*  User Variables              */
	bool PlayerFacingRight; //need to get rid of
	bool PlayerOnGround; //for player jumping, player must be on the ground to jump
	bool canJump; //part of the jump code
	bool CanPlayerShootR; //need to change since player will not be drawn left
	bool keyPressedLastFrame; //so jump and mouse clicks do not operate more than once per button press
	bool PlayerOnPlatform; // for player jumping, acts like player on ground code
	bool PlayerTouchingBottom; // for player colliding with the bottom of a platform, w/o this player gets stuck on platforms when jumping
	bool drawLaser; //for determining whether to draw the laser door or not
	bool isLitUp[4]; // for mini game in part 1
	bool isPlayerDead;

	int buttonX[4]; //for mini game in part 1
	int buttonY[4]; //for mini game in part 1
	int buttonWidth[4]; //for mini game in part 1
	int buttonHeight[4]; //for mini game in part 1
	int LightX[4]; //for mini game in part 1
	int LightY[4]; //for mini game in part 1
	
	int playerX; //player X coord
	int playerY; //player Y coord
	int playerHP; //player health
	int jump; //for jumping
	int jumpHeight; //max player jump height
	int enemyX[5]; //enemy X coord
	int enemyY[5]; //enemy Y coord
	int side[5]; //for enemy movement
	int enemyHP[5]; //enemy health
	bool enemyDead[5]; //for checking if enemy is dead or not

	int cameraX; //camera X coord
	int cameraY; //camera Y coord
	
	int bulletXR; //bullet X coord, need to change name since player will not be drawn left

	int boxX; //floor X coord
	int boxWidth; //floor width coord
	int boxY; //floor Y coord
	int boxHeight; //floor height coord

	int platformX[NBOXES]; //level platforms X coord
	int platformY[NBOXES]; //level platforms Y coord
	int platformWidth[NBOXES]; //level platforms width coord
	int platformHeight[NBOXES]; //level platforms height coord
	int nPlatforms; //how many level platforms

	int holeX; //level death hole X coord
	int holeY; //level death hole Y coord
	int holeWidth; //level death hole width coord
	int holeHeight; //level death hole height coord

	int cx; //teleporter X coord
	int cy; //teleporter Y coord
	int ParticleX[5]; //teleporter FX X coord
	int ParticleY[5];// teleporter FX Y coord
	int rad; // teleporter radius

	
/********************************/
};